@@ -198,6 +198,7 @@ def get_kpts(xml_data, skipk = 0):
     #KPath solved.
     kpath = get_space_info(xml_data).cartesian_kpath[skipk:]
     kpath = kpath - kpath[0] # Shift to start at 0
+    kpath = kpath/kpath[-1] # Normaliz to 1 to see all bandstuructres on common axis in full range
     # Do Not Join KPath if it is broken, leave that to plotting functions
     return serializer.Dict2Data({'NKPTS':len(kpoints),'kpoints':kpoints,'kpath':kpath})
 
@@ -440,15 +441,14 @@ def get_structure(xml_data):
             'positions': np.array(positions),'labels':labels,'unique': unique_d}
     return serializer.PoscarData(st_dic)
 
-def export_vasprun(path = None, skipk = None, elim = [], shift_kpath = 0, dos_only = False):
+def export_vasprun(path = None, skipk = None, elim = [], dos_only = False):
     """
     - Returns a full dictionary of all objects from `vasprun.xml` file. It first try to load the data exported by powershell's `Export-VR(Vasprun)`, which is very fast for large files. It is recommended to export large files in powershell first.
     - **Parameters**
         - path       : Path to `vasprun.xml` file. Default is `'./vasprun.xml'`.
         - skipk      : Default is None. Automatically detects kpoints to skip.
         - elim       : List [min,max] of energy interval. Default is [], covers all bands.
-        - shift_kpath: Default 0. Can be used to merge multiple calculations on single axes side by side.
-    
+        
     **Returns**: `pivotpy.serializer.VasprunData` object.
     """
     path = path or './vasprun.xml'
@@ -504,8 +504,7 @@ def export_vasprun(path = None, skipk = None, elim = [], shift_kpath = 0, dos_on
     #Dimensions dictionary.
     dim_dic={'kpoints':'(NKPTS,3)','kpath':'(NKPTS,1)','bands':'⇅(NKPTS,NBANDS)','dos':'⇅(grid_size,3)','pro_dos':'⇅(NION,grid_size,en+pro_fields)','pro_bands':'⇅(NION,NKPTS,NBANDS,pro_fields)'}
     #Writing everything to be accessible via dot notation
-    kpath = [k + shift_kpath for k in kpts.kpath]  # shift kpath for side by side calculations.
-    full_dic={'sys_info':info_dic,'dim_info':dim_dic,'kpoints':kpts.kpoints,'kpath':kpath,'bands':eigenvals,
+    full_dic={'sys_info':info_dic,'dim_info':dim_dic,'kpoints':kpts.kpoints,'kpath':kpts.kpath,'bands':eigenvals,
              'tdos':tot_dos,'pro_bands':pro_bands,'pro_dos':pro_dos,'poscar': poscar,
              'force':force,'scsteps':scsteps}
     return serializer.VasprunData(full_dic)
@@ -828,9 +827,9 @@ def export_outcar(path=None):
     final_dict = {'ion_pot':pot_arr,'positions':pos_arr,'site_pot':pos_pot,'basis':basis[:,:3],'rec_basis':basis[:,3:],'n_kbi':n_kbi}
     return serializer.OutcarData(final_dict)
 
-def export_locpot(locpot=None,e = True,m = False):
+def export_locpot(locpot = None,e = True,m = False):
     """
-    - Returns Data from LOCPOT and similar structure files like CHG. Loads only single set out of 2/4 magnetization data to avoid performance/memory cost while can load electrostatic and one set of magnetization together.
+    - Returns Data from LOCPOT and similar structure files like CHG/PARCHG etc. Loads only single set out of 2/4 magnetization data to avoid performance/memory cost while can load electrostatic and one set of magnetization together.
     - **Parameters**
         - locpot: path/to/LOCPOT or similar stuructured file like CHG. LOCPOT is auto picked in CWD.
         - e     : Electric potential/charge density. Default is True.
@@ -838,14 +837,9 @@ def export_locpot(locpot=None,e = True,m = False):
     - **Exceptions**
         - Would raise index error if magnetization density set is not present in LOCPOT/CHG in case `m` is not False.
     """
-    if locpot is None:
-        if os.path.isfile('LOCPOT'):
-            locpot = 'LOCPOT'
-        else:
-            raise FileNotFoundError('./LOCPOT not found.')
-    else:
-        if not os.path.isfile(locpot):
-            raise FileNotFoundError("File {!r} does not exist!".format(locpot))
+    path = locpot or './LOCPOT'
+    if not os.path.isfile(locpot):
+        raise FileNotFoundError("File {!r} does not exist!".format(path))
     if m not in [True,False,'x','y','z']:
         raise ValueError("m expects one of [True,False,'x','y','z'], got {}".format(e))
     # data fixing after reading islice from file.
@@ -858,7 +852,7 @@ def export_locpot(locpot=None,e = True,m = False):
         data = data.reshape(N_reshape).transpose([2,1,0])
         return data
     # Reading File
-    with open(locpot,'r') as f:
+    with open(path,'r') as f:
         lines = []
         f.seek(0)
         for i in range(8):
@@ -897,12 +891,5 @@ def export_locpot(locpot=None,e = True,m = False):
     # Read Info
     from .sio import export_poscar # Keep inside to avoid import loop
     poscar_data = export_poscar(text_plain = '\n'.join(p.strip() for p in poscar))
-    basis = poscar_data.basis
-    system = poscar_data.SYSTEM
-    ElemName = list(poscar_data.unique.keys())
-    ElemIndex = [0,*[v[-1]+ 1 for v in poscar_data.unique.values()]]
-    positions = poscar_data.positions
-
-    final_dict = dict(SYSTEM=system,ElemName=ElemName,ElemIndex=ElemIndex,basis=basis,positions=positions)
-    final_dict = {**final_dict,**pot_dict}
-    return serializer.LocpotData(final_dict)
+    final_dict = dict(SYSTEM = poscar_data.SYSTEM, path = path, **pot_dict, poscar = poscar_data)
+    return serializer.GridData(final_dict)
